summaryrefslogtreecommitdiff
path: root/include/parameters.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/parameters.h')
-rw-r--r--include/parameters.h23
1 files changed, 21 insertions, 2 deletions
diff --git a/include/parameters.h b/include/parameters.h
index 138d973..b4aca16 100644
--- a/include/parameters.h
+++ b/include/parameters.h
@@ -13,6 +13,11 @@
namespace Php {
/**
+ * Forward declarations
+ */
+class Base;
+
+/**
* Class definition
*/
class Parameters : public std::vector<Value>
@@ -20,15 +25,29 @@ class Parameters : public std::vector<Value>
public:
/**
* Constructor
* @param argc Number of arguments
* @param tsrm_ls
*/
- Parameters(int argc);// TSRMLS_DC);
+ Parameters(struct _zval_struct *this_ptr, int argc);// TSRMLS_DC);
/**
* Destructor
*/
virtual ~Parameters() {}
+
+ /**
+ * The the object that is called
+ * @return Base
+ */
+ Base *object();
+
+private:
+ /**
+ * The this pointer
+ * @var zval
+ */
+ struct _zval_struct *_this;
};
/**
@@ -20,15 +25,29 @@ class Parameters : public std::vector<Value>
/**
* Constructor
- * @param argc Number of arguments
+ * @param this_ptr Optional this_ptr
+ * @param argc Number of arguments
* @param tsrm_ls
*/